# ifndef yyMakeForall
# define yyMakeForall

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* MakeForall_Exit) ARGS ((void));

extern void MakeForall ARGS ((tTree t));

extern void BeginMakeForall ARGS ((void));
extern void CloseMakeForall ARGS ((void));

# endif
